# /packages/photo-album/www/album-edit.tcl

ad_page_contract {

    Edit Photo Properties

    @author Tom Baginski (bags@arsdigita.com)
    @creation-date 12/11/2000
    @cvs_id $Id: album-edit.tcl,v 1.1 2002/07/09 17:35:10 rmello Exp $
} {
    album_id:integer,notnull
} -validate {
    valid_album -requires {album_id:integer} {
	if [string equal [pa_is_album_p $album_id] "f"] {
	    ad_complain "The specified album is not valid."
	}
    }
} -properties {
    context_list:onevalue
}

ad_require_permission $album_id "write"

set user_id [ad_conn user_id]
set context_list [pa_context_bar_list -final "Edit Album Attributes" $album_id]

template::form create edit_album

template::element create edit_album album_id -label "album ID" \
  -datatype integer -widget hidden

template::element create edit_album revision_id -label "revision ID" \
  -datatype integer -widget hidden

template::element create edit_album previous_revision -label "previous_revision" \
  -datatype integer -widget hidden

template::element create edit_album title -html { size 30 } \
  -label "Album Name" -datatype text

template::element create edit_album description -html { size 50} \
  -label "Album Description"  -datatype text -optional

template::element create edit_album story -html { cols 50 rows 4 wrap soft } \
  -label "Album Story" -datatype text -widget textarea -optional

# this needs to be outside of the s_request block so title attribute
# is defined during a form error

db_1row get_album_info {
    select 
      cr.title,
      cr. description,
      pa.story,
      ci.live_revision as previous_revision
    from cr_items ci,
      cr_revisions cr,
      pa_albums pa
    where ci.live_revision = cr.revision_id
      and cr.revision_id = pa.pa_album_id
      and ci.item_id = :album_id
}


if { [template::form is_request edit_album] } {
    set revision_id [db_nextval acs_object_id_seq]
    template::element set_properties edit_album revision_id -value $revision_id
    template::element set_properties edit_album album_id -value $album_id
    template::element set_properties edit_album previous_revision -value $previous_revision
    template::element set_properties edit_album title -value $title
    template::element set_properties edit_album description -value $description
    template::element set_properties edit_album story -value $story
}

if { [template::form is_valid edit_album] } {
    set album_id [template::element::get_value edit_album album_id]
    set revision_id [template::element::get_value edit_album revision_id]
    set new_title [template::element::get_value edit_album title]
    set new_desc [template::element::get_value edit_album description]
    set new_story [template::element::get_value edit_album story]
    set previous_revision [template::element::get_value edit_album previous_revision]
    set peeraddr [ad_conn peeraddr]

    db_transaction {
	db_exec_plsql update_album_attributes {
	    declare
	      dummy integer;
	    begin

	    dummy := content_revision.new (
	      title         => :new_title,
	      description   => :new_desc,
	      item_id       => :album_id,
	      revision_id   => :revision_id,
	      creation_date => sysdate,
	      creation_user => :user_id,
	      creation_ip   => :peeraddr
	    );

	    end;
	}
	
	db_dml insert_pa_albums {
	    insert into pa_albums (pa_album_id, story)
	    values 
	    (:revision_id, :new_story)
	}
	
	db_exec_plsql set_live_album {
	    content_item.set_live_revision (
	      revision_id => :revision_id
	    )
	}
    } on_error {
	ad_return_complaint 1 "An error occurred while processing your input. Please let the system owner know about this.
	  <pre>$errmsg</pre>"
	
	ad_script_abort
    }
    ad_returnredirect "album?album_id=$album_id"
    ad_script_abort
}

ad_return_template
