# /packages/photo-album/www/album.tcl

ad_page_contract {

    Album display page.

    @author Tom Baginski (bags@arsdigita.com)
    @creation-date 12/10/2000
    @cvs-id $Id: album.tcl,v 1.1 2002/07/09 17:35:10 rmello Exp $
} {
    album_id:integer,notnull
    {page:integer,notnull "1"}
} -validate {
    valid_album -requires {album_id:integer} {
	if [string equal [pa_is_album_p $album_id] "f"] {
	    ad_complain "The specified album is not valid."
	}
    }
} -properties {
    album_id:onevalue
    title:onevalue
    description:onevalue
    story:onevalue
    context_list:onevalue
    child_photo:multirow
    page_nav:onevalue
    admin_p:onevalue
    photo_p:onevalue
    write_p:onevalue
    move_p:onevalue
    delete_p:onevalue
}

set user_id [ad_conn user_id]

# check for read permission on album
ad_require_permission $album_id read

set context_list [pa_context_bar_list $album_id]

db_1row get_album_info {
select cr.title,
  cr.description,
  pa.story,
  ci.parent_id as parent_folder_id,
  decode(acs_permission.permission_p(ci.item_id, :user_id, 'admin'),'t',1,0) as admin_p,
  decode(acs_permission.permission_p(ci.item_id, :user_id, 'pa_create_photo'),'t',1,0) as photo_p,
  decode(acs_permission.permission_p(ci.item_id, :user_id, 'write'),'t',1,0) as write_p,
  decode(acs_permission.permission_p(ci.parent_id, :user_id, 'write'),'t',1,0) as folder_write_p,
  decode(acs_permission.permission_p(ci.item_id, :user_id, 'delete'),'t',1,0) as album_delete_p
from cr_items ci,
  cr_revisions cr,
  pa_albums pa
where ci.live_revision = cr.revision_id
  and ci.live_revision = pa_album_id
  and ci.item_id = :album_id
}

# to move an album need write on album and write on parent folder
set move_p [expr $write_p  && $folder_write_p]

# to delete an album, album must be empty, need delete on album, and write on parent folder
set has_children_p [expr [pa_count_photos_in_album $album_id] > 0]
set delete_p [expr !($has_children_p) && $album_delete_p && $folder_write_p]

# change design so permission checks stop at the album level
# load testing showed serious performance problems when 
# each photo could have individual permissions
# 
# for now all photo in an album inherit the permission of the album that
# contains them.  Only need to check the read permission of the album, which was done at the top of the page. 

set photos_on_page [pa_all_photos_on_page $album_id $page]

if {$has_children_p && [llength $photos_on_page] > 0} {
    # query gets all child photos in album
    # I query the data without an orderby in the sql to cut the querry time
    # and then sort the returned data manually while constructing the multirow datasource.
    # This goes against the theory of let oracle do the hard work, but load testing and
    # query tuning showed that the order by doubled the query time while sorting a few rows in tcl was fast

    # wtem@olywa.net, 2001-09-24
    set photo_sql "
    select ci.item_id as photo_id,
      (select pp.caption from pa_photos pp where pp.pa_photo_id = ci.live_revision) as caption,
      i.image_id as thumb_path,
      i.height as thumb_height,
      i.width as thumb_width
    from cr_items ci,
      cr_items ci2,
      cr_child_rels ccr2,
      imagesx i
    where ccr2.relation_tag = 'thumb'
      and ci.item_id = ccr2.parent_id
      and ccr2.child_id = ci2.item_id
      and ci2.live_revision = i.image_id
      and ci.item_id in ([join $photos_on_page ","])
    "

    db_foreach get_child_photos $photo_sql {
	set val(photo_id) $photo_id
	set val(caption) $caption
	set val(thumb_path) $thumb_path
	set val(thumb_height) $thumb_height
	set val(thumb_width) $thumb_width
	set child($photo_id) [array get val]
    }
    
    # if the structure of the multirow datasource ever changes, this needs to be rewritten    
    set counter 0
    foreach id $photos_on_page {
	incr counter 
	foreach {key value} $child($id) {
	    set child_photo:${counter}($key) $value
	}
    }
    set child_photo:rowcount $counter

    set total_pages [pa_count_pages_in_album $album_id]
    set page_nav [pa_pagination_page_number_links $page $total_pages]

} else {
    # don't bother querying for children if we know they don't exist
    set child_photo:rowcount 0
    set page_nav ""
}
ad_return_template


