# /packages/photo-album/www/photo-add-2.tcl

ad_page_contract {
    adds a photo to an album

    @author bags@arsdigita.com
    @creation-date 12/10/2000
    @cvs-id $Id: photo-add-2.tcl,v 1.1 2002/07/09 17:35:10 rmello Exp $
} {
    upload_file:notnull,trim
    upload_file.tmpfile:tmpfile
    album_id:integer,notnull
    photo_id:integer,notnull
    {description [db_null]}
    {caption [db_null]}
    {story [db_null]}
} -validate {
    valid_album -requires {album_id:integer} {
	if [string equal [pa_is_album_p $album_id] "f"] {
	    ad_complain "The specified album is not valid."
	}
    }
    valid_photo_id -requires {photo_id:integer} {
	# supplied photo_id must not already exist	
	if {[db_string check_photo_id "select count(*) from cr_items where item_id = :photo_id"]} {
	    ad_complain "The specified photo_id already exists"
	}
    }
    valid_mime_type -requires {upload_file:notnull} {
	if {[string first [ns_guesstype $upload_file] [ad_parameter AcceptableUploadMIMETypes]] == -1} {
	    ad_complain "The specified upload photo is not of the appropriate file types. <br>  
	    Must be one of the following: <pre>[ad_parameter AcceptableUploadMIMETypes]</pre>"
	}
    }
}
ns_log Debug "photo-add-2.tcl: Done uploading user file, $upload_file"
set user_id [ad_conn user_id]

#check permission
ad_require_permission $album_id "pa_create_photo"

# wtem@olywa.net, 2001-09-23
# this goes away
# set upload_base "[acs_root_dir]/[ad_parameter PhotoDir]"

set tmp_filename [ns_queryget upload_file.tmpfile]

set file_extension [string tolower [file extension $upload_file]]

# remove the first . from the file extension
regsub "\." $file_extension "" file_extension

set base_n_bytes [file size $tmp_filename]

# strip off the C:\directories... crud and just get the file name
if ![regexp {([^/\\]+)$} $upload_file match client_filename] {
    # couldn't find a match
    set client_filename $upload_file
}

# Create all the ids will need
# ids are created in advance because they are used as part of the 
# file names used to store the images.  

set var_names [list photo_rev_id base_item_id base_rev_id thumb_item_id thumb_rev_id viewer_item_id viewer_rev_id]
foreach name $var_names {
    set $name [db_nextval "acs_object_id_seq"]
}

foreach var [list base_width base_height thumb_height thumb_width viewer_height viewer_width] {
    set $var [db_null]
}

# get the size of the uploaded image
pa_image_width_height $tmp_filename "base_width" "base_height"

# create new filename for uploaded photo and 
# copy to correct location in filesystem

# wtem@olywa.net, 2001-09-23
# change innards
set base_filename_with_rel_path [cr_create_content_file $base_item_id $base_rev_id $tmp_filename]
ns_log notice "what is tmp_filename : $tmp_filename"
ns_log notice "what is base_filename_with_rel_path : $base_filename_with_rel_path"

regexp {.*/([^/]+)$} $base_filename_with_rel_path match base_filename

# [pa_make_file_name -assert -ext $file_extension $photo_rev_id]

# wtem@olywa.net, 2001-09-23
# cr does this now
# ns_cp $tmp_filename ${upload_base}/${base_filename}

set base_mime_type [ns_guesstype $client_filename]

# make the viewer and get appropriate data
# all viewer changed to jpegs if not already one
# viewer_filename is relative to upload base
# full filename is relative to computer root

set viewer_size [ad_parameter ViewerSize]

# wtem@olywa.net, 2001-09-23
# reworked to create a viewer version tmp file
# becaue the original order was different than what the cr wants
set tmp_photo_album_dir_path [ad_parameter FullTempPhotoDir]
if ![file exists $tmp_photo_album_dir_path] {
    ns_log Debug "Making: tmp_photo_album_dir_path"
    ns_mkdir $tmp_photo_album_dir_path
}
set viewer_filename [pa_make_file_name -ext jpg $viewer_rev_id]
set full_viewer_filename "${tmp_photo_album_dir_path}/${viewer_filename}"
pa_make_new_image $tmp_filename ${full_viewer_filename} $viewer_size
pa_image_width_height ${full_viewer_filename} "viewer_width" "viewer_height"
set viewer_n_bytes [file size ${full_viewer_filename}]
set viewer_mime_type [ns_guesstype $viewer_filename]
# now copy the viewer tmp file to the revision's place in the file-system
# change innards
set viewer_filename_with_rel_path [cr_create_content_file $viewer_item_id $viewer_rev_id ${full_viewer_filename}]
regexp {.*/([^/]+)$} $viewer_filename_with_rel_path match viewer_filename

# make the thumb and get appropriate info about thumb
# all thumbnails changed to jpegs if not already one
# 
# thumbnail is made from the viewer image. This is much faster
# than creating the thumbnail from the base image, and doesn't
# seem to alter the image quality of the thumbnail
# If the system is using large thumbnails and image quality is
# more important than upload/processing speed, switch to creating the 
# thumbnail from the base image. 

set thumb_size [ad_parameter ThumbnailSize]
set thumb_filename [pa_make_file_name -ext jpg $thumb_rev_id]
set full_thumb_filename "${tmp_photo_album_dir_path}/${thumb_filename}"
pa_make_new_image ${full_viewer_filename} ${full_thumb_filename} $thumb_size
pa_image_width_height ${full_thumb_filename} "thumb_width" "thumb_height"
set thumb_n_bytes [file size ${full_thumb_filename}]
set thumb_mime_type [ns_guesstype $thumb_filename]
# copy the tmp file to the cr's file-system
set thumb_filename_with_rel_path [cr_create_content_file $thumb_item_id $thumb_rev_id ${full_thumb_filename}]
regexp {.*/([^/]+)$} $thumb_filename_with_rel_path match thumb_filename

# stuff all the correct info into the database
set peeraddr [ad_conn peeraddr]

db_transaction {
    db_exec_plsql insert_photo {
	declare 
	  dummy  integer;
	begin

	dummy := pa_photo.new (
	  name            => :client_filename,
	  parent_id       => :album_id,
	  item_id         => :photo_id,
	  revision_id     => :photo_rev_id,
	  creation_date   => sysdate,
	  creation_user   => :user_id,
	  creation_ip     => :peeraddr,
	  context_id      => :album_id,
	  title           => :client_filename,
	  description     => :description,
	  is_live         => 't',
	  caption         => :caption,
	  story           => :story,
	  user_filename   => :client_filename
	);
	end;
    }  
    
    # wtem@olywa.net, 2001-09-24
    db_exec_plsql insert_base_image {
	declare 
	  dummy  integer;
	begin

	dummy := image.new (
	  name            => 'base_' || :client_filename,
	  parent_id       => :photo_id,
	  item_id         => :base_item_id,
	  revision_id     => :base_rev_id,
	  creation_date   => sysdate,
	  creation_user   => :user_id,
	  creation_ip     => :peeraddr,
	  context_id      => :photo_id,
	  title           => :client_filename,
	  description     => :description,
	  mime_type       => :base_mime_type,
	  relation_tag    => 'base',
	  is_live         => 't',
	  path            => :base_filename_with_rel_path,
	  height          => :base_height,
	  width           => :base_width,
	  file_size       => :base_n_bytes
	);
	end;
    }

    # wtem@olywa.net, 2001-09-24
    db_exec_plsql insert_thumb_image {
	declare 
	  dummy  integer;
	begin

	dummy := image.new (
	  name            => 'th_' || :client_filename,
	  parent_id       => :photo_id,
	  item_id         => :thumb_item_id,
	  revision_id     => :thumb_rev_id,
	  creation_date   => sysdate,
	  creation_user   => :user_id,
	  creation_ip     => :peeraddr,
	  context_id      => :photo_id,
	  title           => :client_filename,
	  description     => :description,
	  mime_type       => :thumb_mime_type,
	  relation_tag    => 'thumb',
	  is_live         => 't',
	  path            => :thumb_filename_with_rel_path,
	  height          => :thumb_height,
	  width           => :thumb_width,
	  file_size       => :thumb_n_bytes
	);
	end;
    }

    # wtem@olywa.net, 2001-09-24
    db_exec_plsql insert_viewer_image {
	declare 
	  dummy  integer;
	begin

	dummy := image.new (
	  name            => 'vw_' || :client_filename,
	  parent_id       => :photo_id,
	  item_id         => :viewer_item_id,
	  revision_id     => :viewer_rev_id,
	  creation_date   => sysdate,
	  creation_user   => :user_id,
	  creation_ip     => :peeraddr,
	  context_id      => :photo_id,
	  title           => :client_filename,
	  description     => :description,
	  mime_type       => :viewer_mime_type,
	  relation_tag    => 'viewer',
	  is_live         => 't',
	  path            => :viewer_filename_with_rel_path,
	  height          => :viewer_height,
	  width           => :viewer_width,
	  file_size       => :viewer_n_bytes
	);
	
	end;
    }

    pa_grant_privilege_to_creator $photo_id $user_id

} on_error {
    # most likely a duplicate name or a double click
    
    if [db_string duplicate_check "
    select count(*)
    from   cr_items
    where  (item_id = :photo_id or name = :client_filename)
    and    parent_id = :album_id"] {
	ad_return_complaint 1 "Either there is already an photo with the name \"$client_filename\" 
	    or you clicked on the button more than once. You can <a href=\"album?album_id=$album_id\">
	    return to the album listing</a> to see if your photo is there."
    } else {
	ad_return_complaint 1 "We got an error that we couldn't readily identify.  Please let the system owner know about this.
	
	<pre>$errmsg</pre>"
    }
    
    ad_script_abort
}

pa_flush_photo_in_album_cache $album_id

# page used as part of redirect so user returns to the album page containing the newly uploaded photo
set page [pa_page_of_photo_in_album $photo_id $album_id]

ad_returnredirect "album?album_id=$album_id&page=$page"
