#/packages/photo-album/www/photo-move.tcl

ad_page_contract {
    Allows user to move a photo from one album to another album in the same folder

    @author Tom Baginski (bags@arsdigita.com)
    @creation-date 12/20/2000
    @cvs-id $Id: photo-move.tcl,v 1.1 2002/07/09 17:35:10 rmello Exp $
} {
    photo_id:integer,notnull
} -validate {
    valid_photo -requires {photo_id:integer} {
	if [string equal [pa_is_photo_p $photo_id] "f"] {
	    ad_complain "The specified photo is not valid."
	}
    }
}
set context_list [pa_context_bar_list -final "Move Photo" $photo_id]
set user_id [ad_conn user_id]

# to move a photo need write on photo, and old parent album
# and pa_create_photo on new parent album (which is check in the is_valid block)

set old_album_id [db_string get_parent_album "select parent_id from cr_items where item_id = :photo_id"]
ad_require_permission $photo_id write


ad_require_permission $old_album_id write

db_1row get_photo_info {select 
      cr.title,
      i.height as height,
      i.width as width,
      i.image_id as image_id
    from cr_items ci,
      cr_revisions cr,
      cr_items ci2,
      cr_child_rels ccr2,
      images i
    where ci.live_revision = cr.revision_id
      and ci.item_id = ccr2.parent_id
      and ccr2.child_id = ci2.item_id
      and ccr2.relation_tag = 'thumb'
      and ci2.live_revision = i.image_id
      and ci.item_id = :photo_id
}

set path $image_id

# build form

template::form create move_photo

template::element create move_photo photo_id -label "photo ID" \
  -datatype integer -widget hidden

template::element create move_photo new_album_id -label "Choose New Album for Photo" \
  -datatype integer -widget select \
  -options [db_list_of_lists get_albums "select r.title as name, i.item_id
    from cr_items i, cr_revisions r
    where i.live_revision = r.revision_id
      and i.parent_id = (select parent_id from cr_items where item_id = :old_album_id)
      and acs_permission.permission_p(i.item_id, :user_id, 'read') = 't'
      and i.content_type = 'pa_album'
      and i.item_id != :old_album_id"]

if { [template::form is_request move_photo] } {
    template::element set_properties move_photo photo_id -value $photo_id
}

if { [template::form is_valid move_photo] } {
    set new_album_id [template::element::get_value move_photo new_album_id]

    ad_require_permission $new_album_id "pa_create_photo"

    if [string equal [pa_is_album_p $new_album_id] "f"] {
	# may add some sort of error message
	# but this case only happens due to url hacking
	# (or coding errors, which never happen)
	ad_script_abort
    }

    db_transaction {
        
        # not using content_item move because is only accepts 
        # a folder_id as target not another content_item

	db_dml photo_move "
	update cr_items
	set parent_id = :new_album_id
	where item_id = :photo_id
	"
	
	db_dml photo_move2 "
	update cr_child_rels 
	set parent_id = :new_album_id
	where parent_id = :old_album_id
	  and child_id = :photo_id
	"
	
	db_dml context_update "
	update acs_objects
	set    context_id = :new_album_id
	where  object_id = :photo_id
	"
	
    } on_error {
	# most likely a duplicate name or a double click
	
	set filename [db_string filename "
	select name from cr_items where item_id = :photo_id"]
	
	if [db_string duplicate_check "
	select count(*)
	from   cr_items
	where  name = :filename
	and    parent_id = :new_album_id"] {
	    ad_return_complaint 1 "Either there is already a photo in the specified albumr with the name \"$filename\" or you clicked on the button more than once.  You can <a href=\"album?album_id=$new_album_id\">return to the new album</a> to see if your photo is there."
	} else {
	    ad_return_complaint 1 "We got an error that we couldn't readily identify.  Please let the system owner know about this.

	    <pre>$errmsg</pre>"
	}
	
	ad_script_abort
    }

    pa_flush_photo_in_album_cache $old_album_id
    pa_flush_photo_in_album_cache $new_album_id
    
    #page used to redirect user to the page of new album containing moved photos
    set page [pa_page_of_photo_in_album $photo_id $new_album_id]
    
    ad_returnredirect "album?album_id=$new_album_id&page=$page"
    ad_script_abort
}

ad_return_template




