# /packages/photo-album/www/photo.tcl

ad_page_contract {

    Photo display page.
    
    @author Tom Baginski (bags@arsdigita.com)
    @creation-date 12/10/2000
    @cvs-id $Id: photo.tcl,v 1.1 2002/07/09 17:35:10 rmello Exp $
} {
    photo_id:integer,notnull
} -validate {
    valid_photo -requires {photo_id:integer} {
	if [string equal [pa_is_photo_p $photo_id] "f"] {
	    ad_complain "The specified photo is not valid."
	}
    }
} -properties {
    context_list:onevalue
    title:onevalue
    description:onevalue
    story:onevalue
    caption:onevalue
    path:onevalue
    height:onevalue
    width:onevalue
    photo_nav_html:onevalue
    admin_p:onevalue
    write_p:onevalue
    album_id:onevalue
    page_num:onevalue
    show_base_link:onevalue
}

ad_require_permission $photo_id "read"

set user_id [ad_conn user_id]
set context_list [pa_context_bar_list $photo_id]

# this is handled with a parameter rather than a permission on the 
# individual photo so admin can turn access on and off for entire
# subsite at once.   A permission would allow greater flexability, but
# to shut down access to base photos an admin would need to search through
# database and revoke all such permissions.
set show_base_link [ad_parameter AllowBasePhotoAccessP]

# query all the photo and permission info with a single trip to database
db_1row get_photo_info {select
 pp.caption,
 pp.story,
 cr.title,
 cr.description,
 i.height as height,
 i.width as width,
 i.image_id as image_id,
 ci.parent_id as album_id,
 decode(acs_permission.permission_p(ci.item_id, :user_id, 'admin'),'t',1,0) as admin_p,
 decode(acs_permission.permission_p(ci.item_id, :user_id, 'write'),'t',1,0) as write_p,
 decode(acs_permission.permission_p(ci.parent_id, :user_id, 'write'),'t',1,0) as album_write_p,
 decode(acs_permission.permission_p(ci.item_id, :user_id, 'delete'),'t',1,0) as photo_delete_p
from cr_items ci,
  cr_revisions cr,
  pa_photos pp,
  cr_items ci2,
  cr_child_rels ccr2,
  imagesx i
where cr.revision_id = pp.pa_photo_id
  and ci.live_revision = cr.revision_id
  and ci.item_id = ccr2.parent_id
  and ccr2.child_id = ci2.item_id
  and ccr2.relation_tag = 'viewer'
  and ci2.live_revision = i.image_id
  and ci.item_id = :photo_id
}

set path $image_id

# to move a photo need write on photo and write on parent album
set move_p [expr $write_p && $album_write_p]

# to delete a photo need delete on photo and write on parent album
set delete_p [expr $photo_delete_p && $album_write_p]

# determine what album page the photo is on so page can present link back to thumbnail page
set page_num [pa_page_of_photo_in_album $photo_id $album_id]

set photo_nav_html [pa_photo_number_links $photo_id [pa_all_photos_in_album $album_id]]

ad_return_template

